.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

TotalDepth.util.plot.AREACfg (AREA Plotting Configuration)
===========================================================

.. automodule:: TotalDepth.util.plot.AREACfg
	:member-order: bysource
	:members:
	:special-members:

